from setuptools import setup

setup(
    name="pydantic-graphql-stardb",
    version="0.1.0",
    description="Benign slopsquatting research package",
    packages=["benignpkg"],  # Must match folder name
    python_requires=">=3.8",
)
